@@ -417,7 +417,7 @@ class CdnClient(AbstractClient):
 
 
     def DescribeIpStatus(self, request):
-        """This API is used to query the status of the edge nodes and intermediate nodes. Note: Edge nodes are only available for beta users now.
+        """This API is used to query the IP details of edge nodes (available soon) and intermediate nodes. Note that there is a certain delay in data availability.
 
         >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/41954?from_cn_redirect=1">corresponding CDN API</a>.
 
