@@ -200,6 +200,35 @@ class CynosdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteBackup(self, request):
+        """This API is used to delete the manual backup for a cluster. It cannot be used to delete the automatic backup.
+
+        :param request: Request instance for DeleteBackup.
+        :type request: :class:`tencentcloud.cynosdb.v20190107.models.DeleteBackupRequest`
+        :rtype: :class:`tencentcloud.cynosdb.v20190107.models.DeleteBackupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteBackup", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteBackupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAccounts(self, request):
         """This API is used to query database management accounts.
 
