@@ -201,6 +201,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDBInstance(self, request):
+        """This API is used to create a monthly subscribed TencentDB instance by passing in information such as instance specifications, database version number, validity period, and quantity.
+
+        :param request: Request instance for CreateDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.CreateDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.CreateDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDBInstance", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateHourDBInstance(self, request):
         """This API is used to create pay-as-you-go instances.
 
@@ -696,6 +725,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePrice(self, request):
+        """This API is used to query the instance price before you purchase it.
+
+        :param request: Request instance for DescribePrice.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribePriceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribePriceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribePrice", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePriceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeProjectSecurityGroups(self, request):
         """This API is used to query the security group details of a project.
 
@@ -900,6 +958,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def KillSession(self, request):
+        """This API is used to kill the specified session.
+
+        :param request: Request instance for KillSession.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.KillSessionRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.KillSessionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("KillSession", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.KillSessionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyAccountDescription(self, request):
         """This API is used to modify the remarks of a TencentDB account.
         Note: accounts with the same username but different hosts are different accounts.
